use crate::util::surrealdb::{client::Time, schemas};
use leptos::*;

/// Renders the home page of your application.
#[component]
pub fn Participants(
    participants: Signal<Vec<schemas::ParticipantSignal>>,
    #[prop(default = true)] show_group: bool,
    #[prop(default = true)] show_lifesaver: bool,
    #[prop(default = true)] show_hindernis: bool,
    #[prop(default = true)] show_popduiken: bool,
) -> impl IntoView {
    view! {
        <table class="participants-table">
            <tr>
                <th>"Naam"</th>
                <Show when=move || show_group>
                    <th>"Groep"</th>
                </Show>
                <Show when=move || show_lifesaver>
                    <th>"Lifesaver"</th>
                </Show>
                <Show when=move || show_hindernis>
                    <th>"Hindernis"</th>
                </Show>
                <Show when=move || show_popduiken>
                    <th>"Popduiken"</th>
                </Show>
            </tr>
            <For
                each=move || participants.get()
                key=|state| state.id.clone()
                let:child
            >
                <tr>
                    <td>{ move || child.value.get().name }</td>
                    <Show when=move || show_group>
                        <td>{ move || child.value.get().group }</td>
                    </Show>
                    { move || match child.value.get().events {
                            Some(events) => view! {
                                <Show when=move || show_lifesaver>
                                    <td>{ Time::from_milliseconds_to_string(events.lifesaver.unwrap_or(0)) }</td>
                                </Show>
                                <Show when=move || show_hindernis>
                                    <td>{ Time::from_milliseconds_to_string(events.hindernis.unwrap_or(0)) }</td>
                                </Show>
                                <Show when=move || show_popduiken>
                                    <td>{ Time::from_milliseconds_to_string(events.popduiken.unwrap_or(0)) }</td>
                                </Show>
                            },
                            None => view! {
                                <td>"0"</td>
                                <td>"0"</td>
                                <td>"0"</td>
                            }
                        }
                    }
                </tr>
            </For>
        </table>
    }
}
